@@ -17,6 +17,7 @@
  */
 
 #include "SceneNode.h"
+#include "Namespace.h"
 #include "../pugixml/src/pugixml.hpp"
 #include <iostream>
 using namespace Savitar;
@@ -70,6 +71,7 @@ void SceneNode::fillByXMLNode(pugi::xml_node xml_node)
 {
     settings.clear();
     id = xml_node.attribute("id").as_string();
+    name = xml_node.attribute("name").as_string();
 
     if(xml_node.child("mesh"))
     {
@@ -95,11 +97,17 @@ void SceneNode::fillByXMLNode(pugi::xml_node xml_node)
     {
         for (pugi::xml_node setting = metadatagroup_node.child("metadata"); setting; setting = setting.next_sibling("metadata"))
         {
+            // NOTE: In theory this could be slow, since we look up the entire ancestry tree for each setting.
+            //       In practice it's expected to be negligible compared to the parsing of the mesh.
+            const xml_namespace::xmlns_map_t namespaces = xml_namespace::getAncestralNamespaces(setting);
+            std::set<std::string> cura_equivalent_namespaces = xml_namespace::getNamesFor(namespaces, xml_namespace::getCuraUri());
+            cura_equivalent_namespaces.insert("cura"); // <- Just to be sure: If there was ever a version out that uses 'cura' without the specification of the xmlns-id.
+
             std::string key = setting.attribute("name").as_string();
             const size_t pos = key.find_first_of(':');
 
-            // Other namespaces can be in the metadata, not just Cura's, don't load those:
-            if (key.substr(0, pos).compare("cura") != 0)
+            // Only accept namespaces cura and implied 'default':
+            if (pos != std::string::npos && cura_equivalent_namespaces.count(key.substr(0, pos)) < 1)
             {
                 continue;
             }
@@ -121,6 +129,16 @@ void SceneNode::setId(std::string id)
     this->id = id;
 }
 
+std::string SceneNode::getName()
+{
+    return this->name;
+}
+
+void SceneNode::setName(std::string name)
+{
+    this->name = name;
+}
+
 std::map< std::string, std::string > SceneNode::getSettings()
 {
     return settings;
