@@ -17,6 +17,7 @@
  */
 
 #include "ThreeMFParser.h"
+#include "Namespace.h"
 #include "Scene.h"
 #include <iostream>
 #include <sstream>
@@ -55,8 +56,8 @@ std::string ThreeMFParser::sceneToString(Scene scene)
     pugi::xml_node build_node = model_node.append_child("build");
 
     model_node.append_attribute("unit") = scene.getUnit().c_str();
-    model_node.append_attribute("xmlns") = "http://schemas.microsoft.com/3dmanufacturing/core/2015/02";
-    model_node.append_attribute("xmlns:cura") = "http://software.ultimaker.com/xml/cura/3mf/2015/10";
+    model_node.append_attribute("xmlns") = xml_namespace::getCuraUri().c_str();
+    model_node.append_attribute("xmlns:cura") = xml_namespace::getDefaultUri().c_str();
     model_node.append_attribute("xml:lang") ="en-US";
 
     for(int i = 0; i < scene.getAllSceneNodes().size(); i++)
@@ -70,6 +71,10 @@ std::string ThreeMFParser::sceneToString(Scene scene)
         // Create item
         pugi::xml_node object = resources_node.append_child("object");
         object.append_attribute("id") = scene_node->getId().c_str();
+        if(!scene_node->getName().empty())
+        {
+            object.append_attribute("name") = scene_node->getName().c_str();
+        }
         object.append_attribute("type") = "model";
 
         if(scene_node->getMeshData().getVertices().size() != 0)
